@@ -5,7 +5,7 @@ use warnings;
 use SQL::Translator::Producer::DBIx::Class::File;
 use GraphQL::Plugin::Convert::DBIC;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my $dbic_schema_class_track = 'CLASS00000';
 sub produce {
@@ -17,7 +17,7 @@ sub produce {
   eval SQL::Translator::Producer::DBIx::Class::File::produce($dbic_translator);
   die "Failed to make DBIx::Class::Schema: $@" if $@;
   my $converted = GraphQL::Plugin::Convert::DBIC->to_graphql(
-    $dbic_schema_class->connect
+    sub { $dbic_schema_class->connect }
   );
   $converted->{schema}->to_doc;
 }
